# Table of Contents

- [getting-started](<./getting-started.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Getting Started](<./Getting-Started.md>)
  - [Introduction to SAP LeanIX](<./Getting-Started/Introduction-to-SAP-LeanIX.md>)
  - [SAP LeanIX Products](<./Getting-Started/SAP-LeanIX-Products.md>)
  - [Key Concepts and Features](<./Getting-Started/Key-Concepts-and-Features.md>)
  - [Who Uses SAP LeanIX](<./Getting-Started/Who-Uses-SAP-LeanIX.md>)
  - [Resources](<./Getting-Started/Resources.md>)
  - [Was this page helpful?](<./Getting-Started/Was-this-page-helpful.md>)
